==> faraway_1.0.2.tar.gz: faraway/man/toenail.Rd <==
\name{toenail}
\alias{toenail}
\docType{data}
\title{Toenail infection treatment study}
\description{
  The data come from a Multicenter study comparing two oral treatments
  for toenail infection. Patients were evaluated for the degree of
  separation of the nail. Patients were randomized into two treatments
  and were followed over seven visits - four in the first year and
  yearly thereafter. The patients have not been treated prior to the
  first visit so this should be regarded as the baseline.
}
\usage{data(toenail)}
\format{
  A data frame with 1908 observations on the following 5 variables.
  \describe{
    \item{\code{ID}}{ID of patient}
    \item{\code{outcome}}{0=none of mild seperation, 1=moderate or severe }
    \item{\code{treatment}}{the treatment A or B}
    \item{\code{month}}{time of the visit (not exactly monthly intervals
    hence not round numbers)}
    \item{\code{visit}}{the number of the visit}
  }
}
\source{
De Backer, M., De Vroey, C., Lesaffre, E., Scheys, I., and De Keyser, P. (1998).
Twelve weeks of continuous oral therapy for toenail onychomycosis caused
by dermatophytes: A double-blind comparative trial of terbinafine 250
mg/day versus itraconazole 200 mg/day. Journal of the American Academy of Dermatology, 38, 57-63.
}
\references{
Lesaffre, E. and Spiessens, B. (2001). On the effect of the number of quadrature 
points in a logistic random-effects model: An example.
Journal of the Royal Statistical 
Society, Series C, 50, 325-335.

G. Fitzmaurice, N. Laird and J. Ware (2004)
Applied Longitudinal Analysis, Wiley

}
\keyword{datasets}

==> faraway_1.0.7.tar.gz: faraway/man/toenail.Rd <==
\name{toenail}
\alias{toenail}
\docType{data}
\title{Toenail infection treatment study}
\description{
  The data come from a Multicenter study comparing two oral treatments
  for toenail infection. Patients were evaluated for the degree of
  separation of the nail. Patients were randomized into two treatments
  and were followed over seven visits - four in the first year and
  yearly thereafter. The patients have not been treated prior to the
  first visit so this should be regarded as the baseline.
}
\usage{data(toenail)}
\format{
  A data frame with 1908 observations on the following 5 variables.
  \describe{
    \item{\code{ID}}{ID of patient}
    \item{\code{outcome}}{0=none or mild seperation, 1=moderate or severe }
    \item{\code{treatment}}{the treatment A=0 or B=1}
    \item{\code{month}}{time of the visit (not exactly monthly intervals
    hence not round numbers)}
    \item{\code{visit}}{the number of the visit}
  }
}
\source{
De Backer, M., De Vroey, C., Lesaffre, E., Scheys, I., and De Keyser, P. (1998).
Twelve weeks of continuous oral therapy for toenail onychomycosis caused
by dermatophytes: A double-blind comparative trial of terbinafine 250
mg/day versus itraconazole 200 mg/day. Journal of the American Academy of Dermatology, 38, 57-63.
}
\references{
Lesaffre, E. and Spiessens, B. (2001). On the effect of the number of quadrature
points in a logistic random-effects model: An example.
Journal of the Royal Statistical
Society, Series C, 50, 325-335.

G. Fitzmaurice, N. Laird and J. Ware (2004)
Applied Longitudinal Analysis, Wiley

}
\keyword{datasets}
